import { EditorView } from '@codemirror/view';
import { Compartment } from '@codemirror/state';
import { lineNumbers } from '@codemirror/gutter';

let gutter = /*@__PURE__*/new Compartment();
function relativeLineNumbers(lineNo, state) {
    if (lineNo > state.doc.lines) {
        return lineNo.toString();
    }
    const cursorLine = state.doc.lineAt(state.selection.asSingle().ranges[0].to).number;
    if (lineNo === cursorLine) {
        return lineNo.toString();
    }
    else {
        return Math.abs(cursorLine - lineNo).toString();
    }
}
// This shows the numbers in the gutter
const showLineNumbers = /*@__PURE__*/gutter.of(/*@__PURE__*/lineNumbers({ formatNumber: relativeLineNumbers }));
// This ensures the numbers update
// when selection (cursorActivity) happens
const lineNumbersUpdateListener = /*@__PURE__*/EditorView.updateListener.of((viewUpdate) => {
    if (viewUpdate.selectionSet) {
        viewUpdate.view.dispatch({
            effects: gutter.reconfigure(lineNumbers({ formatNumber: relativeLineNumbers })),
        });
    }
});
function lineNumbersRelative() {
    return [showLineNumbers, lineNumbersUpdateListener];
}

export { lineNumbersRelative };
